@@ -3,7 +3,7 @@ module OrdinaryDiffEqStabilizedRK
 import OrdinaryDiffEqCore: alg_order, alg_adaptive_order, calculate_residuals!,
                            beta2_default, beta1_default, gamma_default,
                            fac_default_gamma, has_dtnew_modification,
-                           initialize!, perform_step!, @unpack, unwrap_alg,
+                           initialize!, perform_step!, unwrap_alg,
                            calculate_residuals,
                            OrdinaryDiffEqAlgorithm, ispredictive,
                            OrdinaryDiffEqMutableCache, OrdinaryDiffEqConstantCache,
